<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale" exclude-result-prefixes="sc sp op">
  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes"/>
  
  <xsl:param name="vDialog"/>
  <xsl:param name="vAgent"/>

  <xsl:template match="op:text">
    <!-- Contournement pour que les items de liste ne soit pas scénarisés -->
    <vBox isScenarioStep="true" allowChildsScenarisation="false">
      <xsl:apply-templates />
    </vBox>
  </xsl:template>

  <xsl:template match="sc:itemizedList | sc:orderedList">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="sc:itemizedList/sc:listItem">
    <xsl:variable name="vListNumber" select="max(2, count(ancestor::sc:simpleList | ancestor::sc:itemizedList) + 1)" />
    
    <xsl:element name="TB_list_{$vListNumber}">
      <subBlock subType="content">
        <xsl:apply-templates />
      </subBlock>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="sc:orderedList/sc:listItem">
    <TB_list_4>
      <subBlock subType="left">
        <txtListe_2>
          <xsl:value-of select="count(preceding-sibling::sc:listItem)+1"/>
          <xsl:text>.</xsl:text>
        </txtListe_2>
      </subBlock>
      <subBlock subType="content">
        <xsl:apply-templates />
      </subBlock>
    </TB_list_4>
  </xsl:template>

  <xsl:template match="sc:listItem/sc:para" mode="eltName">txtListe_2</xsl:template>
  <xsl:template match="sc:para" mode="eltName">texteSousPage</xsl:template>
   
  <xsl:template match="sc:para">
    <xsl:variable name="vEltName">
      <xsl:apply-templates select="." mode="eltName" />
    </xsl:variable>
    <xsl:variable name="vRepr" select="sc:inlineStyle[@role='representative']" />
    <xsl:variable name="vChildren" select="si($vRepr, $vRepr/* | $vRepr/text(), * | text())" />
    
   
    <xsl:element name="{$vEltName}">
      <xsl:apply-templates select="$vChildren">
        <xsl:with-param name="pRepr" select="$vRepr" />
      </xsl:apply-templates>
    </xsl:element>
        
    <xsl:apply-templates select="$vChildren[self::sc:inlineImg]" mode="list">
      <xsl:with-param name="pRepr" select="$vRepr" />
    </xsl:apply-templates>
  </xsl:template>
   
  <xsl:template match="sc:inlineImg">
    <xsl:param name="pRepr" />
    
    <xsl:text>(</xsl:text>
    <!-- Sélection très compliqué pour compter le nombre d'inlineImg précédent en prenant en charge les inlineStyle représentatifs  -->
    <xsl:value-of select="count(preceding::sc:inlineImg[ancestor::sc:para = current()/ancestor::sc:para
                                                        and (not($pRepr) or ancestor::sc:inlineStyle[@role='representative'])])+1" />
    <xsl:text>)</xsl:text>
  </xsl:template>

  <xsl:template match="sc:inlineImg" mode="list">
    <xsl:param name="pRepr" />
    
    <TB_list_4>
      <subBlock subType="left">
        <txtListe_2>
          <xsl:value-of select="count(preceding::sc:inlineImg[ancestor::sc:para = current()/ancestor::sc:para
                                                              and (not($pRepr) or ancestor::sc:inlineStyle[@role='representative'])])+1" />
          <xsl:text>.</xsl:text>
        </txtListe_2>
      </subBlock>
      <subBlock subType="content">
        <xsl:apply-templates select="." mode="image" />
      </subBlock>
    </TB_list_4>
  </xsl:template>
  
  <xsl:template match="sc:inlineImg[@role='formulaInline']" mode="image">
    <xsl:value-of select="getContent(gotoSubModel(),'inline')" disable-output-escaping="yes" />
  </xsl:template>
  
  <xsl:template match="sc:inlineImg[@role='guiicon']" mode="image">
    <xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
  </xsl:template>

  <xsl:template match="sc:inlineStyle | sc:uLink | sc:textLeaf | sc:phrase">
    <xsl:apply-templates />
  </xsl:template>
  
  <xsl:template match="sc:inlineStyle[@role='emphasis']">
    <emphasis><xsl:apply-templates /></emphasis>
  </xsl:template>
 
  <xsl:template match="sc:uLink[@role='docLink']">
    <a href="co/{getUrl(gotoSubModel(),'')}"><xsl:apply-templates /></a>
  </xsl:template>
  
  <xsl:template match="sc:uLink[not(@role)]">
    <a href="{@url}"><xsl:apply-templates /></a>    
  </xsl:template>
    
  <xsl:template match="text()[normalize-space(.)]">
    <xsl:value-of select="." />
  </xsl:template>
  
  <!-- Cas particulier : les paragraphes commençant par des espaces -->
  <xsl:template match="sc:para/text()[position() = 1 and normalize-space(.)] | sc:member/text()[position() = 1 and normalize-space(.)]">
    <!-- Si le para commence par un espace le booleen renvoyé par starts-with sera converti en 1 -->
    <xsl:value-of select="substring(.,starts-with(.,' ')+1)" />
  </xsl:template>
  
  <xsl:template match="* | text()" />
  
</xsl:stylesheet>
